#/bin/bash

set -exou

mkdir qt-build
pushd qt-build

if [[ $(uname) == "Linux" ]]; then
   USED_BUILD_PREFIX=${BUILD_PREFIX:-${PREFIX}}
   echo USED_BUILD_PREFIX=${BUILD_PREFIX}

   ln -s ${GXX} g++ || true
   ln -s ${GCC} gcc || true
   ln -s ${USED_BUILD_PREFIX}/bin/${HOST}-gcc-ar gcc-ar || true

   export LD=${GXX}
   export CC=${GCC}
   export CXX=${GXX}
   export PKG_CONFIG_EXECUTABLE=$(basename $(which pkg-config))
   export PKG_CONFIG_PATH="$PKG_CONFIG_PATH:/usr/lib64/pkgconfig/"

   chmod +x g++ gcc gcc-ar
   export PATH=${PWD}:${PATH}

   # Copy XCB headers to PREFIX
   #cp -r /usr/include/xcb $PREFIX/include
   NPROC=$(nproc)

  ../configure -prefix ${PREFIX} \
	     -libdir ${PREFIX}/lib \
	     -bindir ${PREFIX}/bin \
	     -headerdir ${PREFIX}/include/qt \
	     -archdatadir ${PREFIX} \
	     -datadir ${PREFIX} \
	     -I ${PREFIX}/include \
	     -L ${PREFIX}/lib \
	     -L ${BUILD_PREFIX}/${HOST}/sysroot/usr/lib64 \
	     QMAKE_LFLAGS+="-Wl,-rpath,$PREFIX/lib -rpath-link,$PREFIX/lib -L$PREFIX/lib" \
	     -opensource \
	     -nomake examples \
	     -nomake tests \
	     -gstreamer 1.0 \
	     -confirm-license \
	     -system-libjpeg \
	     -system-libpng \
	     -system-zlib \
	     -xcb \
	     -xcb-xlib \
	     -bundled-xcb-xinput
fi

if [[ $(uname) == "Darwin" ]]; then

if [[ $target_platform == osx-arm64 ]]; then
    list_config_to_patch=$(find .. -name config.guess | sed -E 's/config.guess//')
    for config_folder in $list_config_to_patch; do
        echo "copying config to $config_folder ...\n"
        cp -v $BUILD_PREFIX/share/libtool/build-aux/config.* $config_folder
    done
fi

  export PATH=${BUILD_PREFIX}/bin:${PATH}

  #export CROSS_COMPILE=$HOST
  #export AR=$(basename ${AR})
  #export RANLIB=$(basename ${RANLIB})
  #export STRIP=$(basename ${STRIP})
  export OBJDUMP=$(basename ${OBJDUMP})
  #export CC=$(basename ${CC})
  #export CXX=$(basename ${CXX})

  # Let Qt set its own flags and vars
  for x in OSX_ARCH CFLAGS CXXFLAGS LDFLAGS
  do
      echo $x # unset $x
   done

    #cp "${RECIPE_DIR}"/xcrun .
    #cp "${RECIPE_DIR}"/xcodebuild .
    # Some test runs 'clang -v', but I do not want to add it as a requirement just for that.
    #ln -s "${CXX}" ${HOST}-clang || true
    # For ltcg we cannot use libtool (or at least not the macOS 10.9 system one) due to lack of LLVM bitcode support.
    #ln -s "${LIBTOOL}" libtool || true
    # Just in-case our strip is better than the system one.
    #ln -s "${STRIP}" strip || true
    #chmod +x ${HOST}-clang libtool strip xcrun xcodebuild
    # Qt passes clang flags to LD (e.g. -stdlib=c++)
    #export LD=${CXX}

  NPROC=$CPU_COUNT

  PLATFORM=""
  if [[ $(arch) == "arm64" ]]; then
    PLATFORM="-device-option QMAKE_APPLE_DEVICE_ARCHS=arm64 -device-option QMAKE_MACOSX_DEPLOYMENT_TARGET=11.1"
    # temporary fix for apple
    # PLATFORM="${PLATFORM} -skip qtwebengine -no-assimp"
  fi
  #export WEBENGINE_OSX_SDK_PRODUCT_VERSION="10.15.0"

  # sed -i '' -E "s|QMAKE_CLANG_DIR = ./usr.|QMAKE_CLANG_DIR = ${BUILD_PREFIX}|g" ../qtwebengine/src/buildtools/config/mac_osx.pri
  ../configure -prefix ${PREFIX} \
             -extprefix ${PREFIX} -sysroot ${CONDA_BUILD_SYSROOT} \
             -archdatadir ${PREFIX} -datadir ${PREFIX} -headerdir ${PREFIX}/include/qt \
             -feature-relocatable \
             -system-sqlite -no-sql-mysql -no-sql-odbc -no-sql-psql -no-guess-compiler \
             -I ${PREFIX}/include -L ${BUILD_PREFIX}/lib -R ${BUILD_PREFIX}/lib -L $PREFIX/lib -R $PREFIX/lib \
    -- ${CMAKE_ARGS} -DCMAKE_INSTALL_PREFIX=$PREFIX -DCMAKE_INSTALL_LIBDIR=lib -DCMAKE_OSX_DEPLOYMENT_TARGET=10.15 \
        -DINSTALL_MKSPECDIR=${PREFIX}/mkspecs -DFEATURE_pkg_config=ON -DFEATURE_qt3d_system_assimp=ON -DTEST_assimp=ON

  cmake --build .  --parallel
  cmake --install .
  rm $PREFIX/bin/"qt-cmake-private-install.cmake"
  /usr/bin/sed -i '' -E "s|${BUILD_PREFIX}|/usr/bin|g" ${PREFIX}/lib/cmake/Qt6/qt.toolchain.cmake
else

# 7/23/2021 PJY: Specifying the CPATH and LD_LIBRARY_PATH seem to be important for
# finding additional headers and libs (e.g. event.h).
CPATH=$PREFIX/include LD_LIBRARY_PATH=$PREFIX/lib make -j${CPU_COUNT} || exit 1

make install
fi

# Remove XCB headers
rm -rf $PREFIX/include/xcb

echo "copy configuration file qt.conf ..."
# Add qt.conf file to the package to make it fully relocatable
cp -f "${RECIPE_DIR}"/qt.conf "${PREFIX}"/bin/

